Module codegen_audit

Module codegen_audit 

Assembly audit harness for verifying codegen quality.

Every pub fn in this module is #[inline(never)] to provide clean symbol boundaries for cargo asm inspection:

cargo asm --lib -p nexus-rt --features codegen-audit "pipe_linear_3"

These functions are NOT part of the public API. They exist solely for codegen verification. The codegen-audit feature flag ensures none of this compiles unless explicitly requested.

Modules

helpers
Shared types, resources, and step functions for codegen audit.

Functions

adapt_by_ref
adapt_cloned
adapt_cloned_string
adapt_decode
adapt_decode_skip
adapt_in_fanout
adapt_nested
adapt_owned_str
batch_dag_diamond
batch_dag_dispatch
batch_dag_fork4
batch_dag_fork_merge
batch_dag_guard
batch_dag_heavy
batch_dag_large
batch_dag_linear_3
batch_dag_linear_10
batch_dag_mixed_arity
batch_dag_nested_fork
batch_dag_option_chain
batch_dag_result_chain
batch_dag_route
batch_dag_splat
batch_pipe_buffer_reuse
batch_pipe_dispatch
batch_pipe_drain_codegen
batch_pipe_empty
batch_pipe_guard
batch_pipe_guard_filter
batch_pipe_guard_skip_10
batch_pipe_large
batch_pipe_linear_3
batch_pipe_linear_10
batch_pipe_mixed_arity
batch_pipe_option_chain
batch_pipe_res_skip_10
batch_pipe_result_chain
batch_pipe_route
batch_pipe_single_item
batch_pipe_splat
batch_pipe_switch
batch_pipe_transition
broadcast_2
broadcast_3
broadcast_4
callback_dispatch
callback_template_dispatch
dag_asymmetric_arms
dag_bool_chain
dag_cloned_bare
dag_cloned_option
dag_cloned_result
dag_dedup
dag_deep_nested_fork
dag_diamond
dag_dispatch
dag_dispatch_fanout
dag_filter
dag_filter_in_arm
dag_fork2_join
dag_fork2_merge
dag_fork2_merge_consume
dag_fork3_join
dag_fork3_merge
dag_fork3_merge_consume
dag_fork4_merge
dag_fork_arm_combinators
dag_fork_heavy_arms
dag_fork_then_chain
dag_fork_with_guard
dag_fork_with_route
dag_full_kitchen_sink
dag_guard
dag_guard_skip_10
dag_linear_1
dag_linear_2
dag_linear_3
dag_linear_5
dag_linear_10
dag_linear_20
dag_linear_mixed_arity
dag_nested_fork
dag_opt_and_then
dag_opt_chain
dag_opt_map
dag_res_and_then
dag_res_catch
dag_res_chain
dag_res_err_skip_10
dag_res_map
dag_res_or_else
dag_route_basic
dag_route_heavy_arms
dag_route_in_arm
dag_route_nested
dag_sequential_forks
dag_splat2
dag_splat3
dag_splat5
dag_splat_in_arm
dag_switch_3way
dag_switch_basic
dag_switch_resolve_arm
dag_tap
dag_tee
dag_tee_heavy
dag_transition_guard_ok_or
dag_wide_fan_out
dag_world_3_params
dag_world_mixed_chain
dag_world_res
dag_world_res_mut
fanout_2
fanout_4
fanout_8
handler_0_param_dispatch
handler_1_param_dispatch
handler_2_param_dispatch
handler_3_param_dispatch
handler_catch_unwind
handler_virtual_dispatch
pipe_bool_and
pipe_bool_chain
pipe_bool_guard_integration
pipe_bool_not
pipe_bool_or
pipe_bool_xor
pipe_cloned_bare
pipe_cloned_copy_type
pipe_cloned_large_type
pipe_cloned_option
pipe_cloned_result
pipe_dedup
pipe_dedup_chain
pipe_dispatch_broadcast
pipe_dispatch_fanout2
pipe_dispatch_fanout4
pipe_dispatch_fanout8
pipe_dispatch_handler
pipe_dispatch_mid_then_continue
pipe_filter_basic
pipe_guard_basic
pipe_guard_large_type
pipe_guard_then
pipe_linear_0_params
pipe_linear_1
pipe_linear_2
pipe_linear_3
pipe_linear_5
pipe_linear_10
pipe_linear_20
pipe_linear_mixed_arity
pipe_opt_and_then
pipe_opt_filter
pipe_opt_filter_inspect_unwrap
pipe_opt_filter_skip_chain
pipe_opt_guard_skip_10
pipe_opt_inspect
pipe_opt_map
pipe_opt_map_5x
pipe_opt_map_and_then
pipe_opt_map_filter
pipe_opt_ok_or
pipe_opt_ok_or_chain
pipe_opt_ok_or_else
pipe_opt_on_none
pipe_opt_triple_filter
pipe_opt_unwrap_or
pipe_opt_unwrap_or_else
pipe_res_and_then
pipe_res_catch
pipe_res_catch_skip_chain
pipe_res_catch_then_option
pipe_res_err_skip_10
pipe_res_inspect
pipe_res_inspect_both
pipe_res_inspect_err
pipe_res_map
pipe_res_map_5x
pipe_res_map_and_then
pipe_res_map_err
pipe_res_map_err_or_else
pipe_res_ok
pipe_res_or_else
pipe_res_unwrap_or
pipe_res_unwrap_or_else
pipe_route_basic
pipe_route_heavy_arms
pipe_route_nested_2
pipe_route_nested_3
pipe_splat3
pipe_splat4
pipe_splat5
pipe_splat2_mid
pipe_splat2_start
pipe_splat_large_types
pipe_splat_then_guard
pipe_splat_with_params
pipe_start_switch
pipe_switch_3way
pipe_switch_basic
pipe_switch_resolve_step
pipe_tap_basic
pipe_tap_multiple
pipe_tap_with_world
pipe_tee_basic
pipe_tee_heavy
pipe_trans_full_lifecycle
pipe_trans_guard_ok_or_catch_unwrap
pipe_trans_guard_ok_or_unwrap
pipe_trans_guard_unwrap
pipe_trans_nested_option
pipe_trans_result_catch_unwrap
pipe_trans_result_in_option
pipe_trans_result_ok_unwrap
pipe_world_3_params
pipe_world_5_params
pipe_world_8_params
pipe_world_local
pipe_world_mixed_chain
pipe_world_res
pipe_world_res_branch
pipe_world_res_mut
pipe_world_res_res_mut
stress_batch_dag_nested
stress_batch_pipe_30_steps
stress_dag_fork_route_mix
stress_dag_wide_fork
stress_mixed_everything
stress_pipe_30_steps
stress_pipe_50_steps
stress_pipe_all_combinators
stress_pipe_dedup_in_batch
stress_pipe_large_type
stress_pipe_many_closures
stress_pipe_route_4_deep
stress_pipe_splat_chain
stress_pipe_tee_in_route
stress_pipe_transition_chain
template_generate_and_dispatch
template_stamp_5