pub type BoundedFlexTimerWheel = BoundedWheel<FlexVirtual<Instant, B256>>;Expand description
Type alias for a bounded timer wheel using inline storage with heap fallback.
Aliased Type
pub struct BoundedFlexTimerWheel { /* private fields */ }pub type BoundedFlexTimerWheel = BoundedWheel<FlexVirtual<Instant, B256>>;Type alias for a bounded timer wheel using inline storage with heap fallback.
pub struct BoundedFlexTimerWheel { /* private fields */ }