pub type BoundedInlineTimerWheel = BoundedWheel<FlatVirtual<Instant, B256>>;Expand description
Type alias for a bounded timer wheel using inline handler storage.
Aliased Type
pub struct BoundedInlineTimerWheel { /* private fields */ }pub type BoundedInlineTimerWheel = BoundedWheel<FlatVirtual<Instant, B256>>;Type alias for a bounded timer wheel using inline handler storage.
pub struct BoundedInlineTimerWheel { /* private fields */ }